{
    /*
     * All build file options are documented here:
     * https://github.com/jrburke/r.js/blob/master/build/example.build.js
     */

    /*
     * The top level directory that contains your app.
     * If this option is used then it assumed your scripts are in a
     * subdirectory under this path.
     */
    appDir: '../www/public',

    /*
     * By default, all modules are located relative to this path. If baseUrl
     * is not explicitly set, then all modules are loaded relative to
     * the directory that holds the build file. If appDir is set, then
     * baseUrl should be specified as relative to the appDir.
     */
    baseUrl: '.',

    /*
     * The directory path to save the output. If not specified, then
     * the path will default to be a directory called "build" as a sibling
     * to the build file.
     */
    dir: '../build',

    /*
     * If you prefer the "main" JS file configuration
     * to be read for the build so that you do not have to duplicate the values
     * in a separate configuration, set this property to the location of that
     * main / config JS file. The first requirejs({}), require({}),
     * requirejs.config({}), or require.config({}) call found in that
     * file will be used.
     */
    mainConfigFile: '../www/public/js/shared.js',

    /*
    * How to optimize all the JS files in the build output directory.
    * Right now only the following values
    * are supported:
    * - "uglify": (default) uses UglifyJS to minify the code.
    * - "uglify2": in version 2.1.2+. Uses UglifyJS2.
    * - "none": no minification will be done.
    */
    optimize: "uglify2",

    /*
     * Uglify2 Options
     * For possible values see:
     * http://lisperator.net/uglifyjs/codegen
     * http://lisperator.net/uglifyjs/compress
     */
    uglify2: {
        output: {
            beautify: false // true outputs more readble minified code
        },
        compress: {
            sequences     : true,  // join consecutive statemets with the “comma operator”
            properties    : true,  // optimize property access: a["foo"] → a.foo
            dead_code     : true,  // discard unreachable code
            drop_debugger : true,  // discard “debugger” statements
            unsafe        : true,  // some unsafe optimizations (see below)
            conditionals  : true,  // optimize if-s and conditional expressions
            comparisons   : true,  // optimize comparisons
            evaluate      : true,  // evaluate constant expressions
            booleans      : true,  // optimize boolean expressions
            loops         : true,  // optimize loops
            unused        : true,  // drop unused variables/functions
            hoist_funs    : true,  // hoist function declarations
            hoist_vars    : false, // hoist variable declarations
            if_return     : true,  // optimize if-s followed by return/continue
            join_vars     : true,  // join var declarations
            cascade       : true,  // try to cascade `right` into `left` in sequences
            side_effects  : true,  // drop side-effect-free statements
            warnings      : false,  // warn about potentially dangerous optimizations/code
            global_defs   : {}     // global definitions
        }
    },

    /*
     * CSS Optimizations.
     * - standard: @import inlining, comment removal and line returns.
     * - standard.keepLines: like "standard" but keeps line returns.
     * - standard.keepComments: keeps the file comments, but removes line returns.
     * - standard.keepComments.keepLines: keeps the file comments and line returns.
     * - none: skip CSS optimizations.
     */
    // CSS compression is handled by compass / scss
    optimizeCss: "none",

    /*
     * List the modul es that will be optimized. All their immediate and deep
     * dependencies will be included in the module's file when the build is done.
     */
    modules: [
        {
            name: 'js/shared',
            include: [
                'modernizr',
                'underscore',
                'backbone'
                'jquery',

                // Twitter Bootstrap Modules
                'bs-affix',
                'bs-alert',
                'bs-button',
                'bs-carousel',
                'bs-collapse',
                'bs-dropdown',
                'bs-modal',
                'bs-popover',
                'bs-scrollspy',
                'bs-tab',
                'bs-transition',
                'bs-typehead'
            ]
        },
        {
            /*
             * Just specifying a module name means that module will be converted into
             * a built file that contains all of its dependencies.
             */
            name: 'js/main',

            // Include additional dependencies into this module
            include: [],

            // Exclude any shared dependencies
            exclude: ['js/shared']
        }
    ]

    // was mangling jwplayer, removed for now
    // wrap: {
    //     start: "(function(window, document) {",
    //     end: "}(window, document));"
    // },
}

