# Vhosts ------------------------------------------------------------------- //

/etc/apache2/sites-available/app-vhost:
  file:
    - managed
    - source: salt://app/files/app-vhost
    - user: root
    - group: root
    - watch_in:
      - service: httpd

/etc/apache2/sites-enabled/000-app:
  file.symlink:
    - target: /etc/apache2/sites-available/app-vhost
  require:
    - file: /etc/apache2/sites-available/app-vhost


# Apache Modules ----------------------------------------------------------- //

enable-mod-rewrite:
  cmd.run:
    - user: root
    - group: root
    - name: /usr/sbin/a2enmod rewrite

    # run this cmd "only if" the a2enmod exists
    - onlyif: command -v a2enmod > /dev/null

    # depends on httpd (apache2)
    - require:
      - pkg: httpd

    # restart httpd if this state changes
    - watch_in:
      - service: httpd


# Apache envvars ----------------------------------------------------------- //
# Note: Do not use this config on any production / stage box

# required because we are changing apache user / group to vagrant in envvars
/var/run/apache2:
  file.directory:
    - user: vagrant
    - group: vagrant
    - mode: 755

# required because we are changing apache user / group to vagrant in envvars
/var/lock/apache2:
  file.directory:
    - user: vagrant
    - group: vagrant
    - mode: 755

# upload new envvars with vagrant set as user / group
# required to work around permission issues on shared folders
/etc/apache2/envvars:
  file:
    - managed
    - source: salt://app/files/envvars
    - user: root
    - group: root
    - require:
      - pkg: httpd
      - file: /var/lock/apache2

    # restart apache should this file change
    - watch_in:
      - service: httpd
