define(
[
    'jquery',
    'underscore',
    'backbone',
    'js/models/async',
    'js/collections/breakpoints'
],

function($, _, Backbone, Async, Breakpoints){
'use strict';

/**
 * @name UserData
 * @description a Mocked UserData model
 * @returns {Backbone.Model}
 * @requires jquery, underscore, backbone
 */

var UserData = Async.extend({
    defaults: {
        breakpointsJson: null, // Raw data
        breakpoints: null // Backbone Collection Breakpoints
    },

    initialize: function() {
        // call super, bake in mock url
        Async.prototype.initialize.apply(this, [{url: 'js/data/mocks/userDataMock.json'}]);

        // changed will fire when data is fetched, updates collections etc.
        this.on(
            {
                'change:breakpointsJson': this.updateBreakpionts
            }
        );
    },

    // Update functions

    updateBreakpionts: function(model, data, options) {
        var attrs = this.attributes;
        attrs.breakpoints = new Breakpoints(data);
    }
});

return UserData;

});
