// ------------------------------------------------------------------------- //
// Require.js Config                                                         //
// ------------------------------------------------------------------------- //

require.config({
    baseUrl: './',
    /*
     * Path mappings for module names not found directly under baseUrl.
     * The path settings are assumed to be relative to baseUrl,
     * unless the paths setting starts with a "/" or has a
     * URL protocol in it ("like http:").
     */
    paths: {
        'modernizr': 'js/vendor/modernizr',
        'jquery': 'js/vendor/jquery',
        'underscore': 'js/vendor/underscore',
        'backbone': 'js/vendor/backbone',
        'mustache': 'js/vendor/mustache',
        'text': 'js/vendor/require/text',

        // Twitter Bootstrap modules
        'bs-affix'     : 'js/vendor/bootstrap/bootstrap-affix',
        'bs-alert'     : 'js/vendor/bootstrap/bootstrap-alert',
        'bs-button'    : 'js/vendor/bootstrap/bootstrap-button',
        'bs-carousel'  : 'js/vendor/bootstrap/bootstrap-carousel',
        'bs-collapse'  : 'js/vendor/bootstrap/bootstrap-collapse',
        'bs-dropdown'  : 'js/vendor/bootstrap/bootstrap-dropdown',
        'bs-modal'     : 'js/vendor/bootstrap/bootstrap-modal',
        'bs-popover'   : 'js/vendor/bootstrap/bootstrap-popover',
        'bs-scrollspy' : 'js/vendor/bootstrap/bootstrap-scrollspy',
        'bs-tab'       : 'js/vendor/bootstrap/bootstrap-tab',
        'bs-transition': 'js/vendor/bootstrap/bootstrap-transition',
        'bs-typehead'  : 'js/vendor/bootstrap/bootstrap-typehead'

        // TODO: Idea, instead of settings.json
        // Services
        // Cleverly mapped to actuall service location, but until those exist
        //  you may map this to the mocks instead.
        // 'js/services/userData': 'js/services/mocks/userData'
    },

    /*
     * Shim configures the dependencies and exports for older, traditional
     * "browser globals" scripts that do not use define() to declare the
     * dependencies and set a module value.
     */
    shim: {
        modernizr: {
            exports: 'Modernizr'
        },
        backbone: {
            deps: ['underscore','jquery'],
            exports: 'Backbone'
        },
        underscore: {
            exports: '_'
        },
        mustache: {
            exports: 'Mustache'
        },

        // Twitter Bootstrap Shims
        'bs-affix': {
            deps: ['jquery']
        },
        'bs-alert': {
            deps: ['jquery']
        },
        'bs-button': {
            deps: ['jquery']
        },
        'bs-carousel': {
            deps: ['jquery']
        },
        'bs-collapse': {
            deps: ['jquery']
        },
        'bs-dropdown': {
            deps: ['jquery']
        },
        'bs-modal': {
            deps: ['jquery']
        },
        'bs-popover': {
            deps: ['jquery']
        },
        'bs-scrollspy': {
            deps: ['jquery']
        },
        'bs-tab': {
            deps: ['jquery']
        },
        'bs-transition': {
            deps: ['jquery']
        },
        'bs-typehead': {
            deps: ['jquery']
        }
    }
});

// Require will append additional "shared" dependencies to the end of this file.
// See require/build.js at "modules: {}" for configuration.
