define(
[
    'jquery',
    'underscore',
    'backbone',
    'js/views/breakpoint-item'
],

function($, _, Backbone, BreakpointItem){
'use strict';

/**
 * @name BreakpointsView
 * @description BreakpointsView, a collection of BreakpointItem(s)
 * @returns {Backbone.View}
 * @requires jquery, underscore, backbone, js/views/breakpoint-view
 */

var BreakpointsView = Backbone.View.extend({
    el: '.content',
    el_item: '.breakpoint',
    collection: false,
    $views: false,


    // Initialize

    initialize: function(collection) {
        this.collection = collection;

        // proxy events
        _.bindAll(
            this,
            'onAdd'
        );

        this.collection.on(
            {
                'add': this.onAdd
            }
        );

        this.update();
    },


    // Methods

    add: function(data) {
        this.collection.add(data);
    },

    /**
     * @name update
     * @description Updates view, but only updates unrendered collection items.
     * @return nothing
     */
    update: function() {
        var i = this.$views.length || 0,
            len = this.collection.length,
            model = null,
            view = null;

        for(i; i < len; i++) {
            model = this.collection.models[i];
            view = new BreakpointItem(model.attributes);

            // add view to content
            this.$el.append(view.render());

            // update reference to views
            this.$views = $(this.el_item);
        }
    },


    // Event Delegates

    onAdd: function(model, collection, options) {
        this.update();
    }

});

return BreakpointsView;

});
