define(
[
    'jquery',
    'underscore',
    'backbone',

    'js/events/dispatcher',

    // views
    'js/views/modal-add-breakpoint',
    'js/views/modal-add-link',
    'js/views/breakpoints-list'
],

function(
    $,
    _,
    Backbone,
    Dispatcher,
    ModalAddBreakpoint,
    ModalAddLink,
    BreakpointsList
) {
'use strict';

/**
 * @name Index
 * @description Index view for the application.
 * @param {Backbone.Router} router The application router.
 * @param {Backbone.Events} dispatcher An event dispatcher mixin.
 * @returns {Backbone.View}
 * @requires jquery, underscore, backbone, js/views/modal-add-breakpoint, js/collections/breakpionts, js/vies/breakpoints-view
 */

var Index = Backbone.View.extend({
    el: 'body',

    // Jquery references
    $addBreakpointBtn: false,

    router: false,
    modalAddBreakpoint: false,
    modalAddLink: false,
    breakpointsList: false,


    // Initialize

    initialize: function(router, userData) {
        this.router = router;
        this.userData = userData;


        // proxy functions
        _.bindAll(
            this,
            'onAddBreakpointClick',
            'onAddLinkClick',
            'onModalAddBreakpointSave',
            'onUserDataLoaded',
            'onModalConfirm'
        );


        // wait for user data loaded
        this.userData.done(this.onUserDataLoaded);
    },

    initializeViews: function(userData) {
        // cache a few elements
        this.$addBreakpointBtn = $('.navbar .js-add-breakpoint');
        this.$addLinkBtn = $('.navbar .js-add-link');


        this.modalAddBreakpoint = new ModalAddBreakpoint();
        this.modalAddLink = new ModalAddLink();
        this.breakpointsList = new BreakpointsList(userData.attributes.breakpoints);

        // initialize events
        Dispatcher.on('modalConfirm', this.onModalConfirm);
        this.$addBreakpointBtn.on('click.index', this.onAddBreakpointClick);
        this.$addLinkBtn.on('click.index', this.onAddLinkClick);
    },


    // Event delegates

    onUserDataLoaded: function(model, response, options, promise) {
        this.initializeViews(model);
    },

    onAddBreakpointClick: function(e) {
        e.preventDefault();
        var $target = $(e.currentTarget);

        this.modalAddBreakpoint.show();
    },

    onAddLinkClick: function(e) {
        e.preventDefault();

        this.modalAddLink.show();
    },

    onModalAddBreakpointSave: function(data) {
        this.breakpointsList.add(data);
    },

    onModalConfirm: function(data) {
        var target = data.target;

        if(target === this.modalAddLink) {
            // stub
            // update user data
        }
        else if(target === this.modalAddBreakpoint) {
            // stub
            // update user data
        }
    }

});

return Index;

});
