define(
[
    'jquery',
    'underscore',
    'backbone',
    'js/events/dispatcher',
    'text!js/templates/modal-base.erb',

    // non-global plugins
    'bs-modal'
],

function(
    $,
    _,
    Backbone,
    Dispatcher,
    TemplateBase
) {
'use strict';

/**
 * @name ModalSimple
 * @description Controls a modal view.
 * @returns {Backbone.View}
 * @requires jquery, underscore, backbone, js/templates/modal-base, js/partials/modal-add-breakpoint
 */

var ModalSimple = Backbone.View.extend({

    el: null, // set when rendered
    $el: null, // set when rendered
    $cancelBtn: null,
    $confirmBtn: null,

    // Initialize

    initialize: function() {

        // proxy functions
        _.bindAll(
            this,
            // 'onAddClick',
            'show',
            'hide',
            'toggle',
            'dispatch',
            'bubbleEvent',
            'onCancel',
            'onConfirm',
            'getFormData'
        );

        // bind base event handlers
    },

    initializeUiEvents: function($context) {
        this.$cancelBtn = $context.find('.js-cancel');
        this.$confirmBtn = $context.find('.js-confirm');

        this.$cancelBtn.on('click', this.onCancel);
        this.$confirmBtn.on('click', this.onConfirm);

        // bubble default TWBS events
        this.$el.on('show shown hide hidden', this.bubbleEvent);
    },

    // Methods

    render: function(model) {
        var html = _.template(TemplateBase, model);

        // update element reference
        this.$el = $(html).modal({show: false});
        this.el = this.$el[0];

        this.initializeUiEvents(this.$el);
    },

    serializeForm: function($context) {
        var pairs = $context.serializeArray(),
            result = {};

        _.map(
            pairs,
            function(pair) {
                result[pair.name] = pair.value;
            }
        );

        return result;
    },


    // Convenience methods around TWBS calls

    show: function() {
        this.$el.modal('show');
    },

    hide: function() {
        this.$el.modal('hide');
    },

    toggle: function() {
        this.$el.modal('toggle');
    },


    // Ui event delegates

    onCancel: function(e) {
        // basic functionality, override in subclass
        this.dispatch('modalCancel', {event: e});
    },

    onConfirm: function(e) {
        this.dispatch('modalConfirm', {
            event: e,
            target: this,
            formData: this.getFormData()
        });

        this.hide();
    },


    // Helpers

    getFormData: function() {
        var $form = $(this.el_form);

        if(!this.el_form || $form.length === 0) {
            throw new Error('No form element found!');
        }

        return this.serializeForm($form);
    },

    dispatch: function(type, data) {
        data = data || {};
        Dispatcher.trigger(type, data);
    },

    bubbleEvent: function(e) {
        this.dispatch(e.type, e);
    }
});

return ModalSimple;

});
